@@ -1,26 +1,29 @@
 class PostInfo:
     def __init__(self,
-                 post_id:str,
-                 author:str,
-                 content:str,
-                 time:str,
-                 images:list = [],
-                 link:str = None
+                 post_id: str,
+                 post_url: str,
+                 author: str,
+                 content: str,
+                 time: str,
+                 images: list = [],
+                 link: str = None
                  ):
         self.id = post_id
+        self.url = post_url
         self.author = author
         self.content = content
         self.time = time
         self.images = images
         self.link = link
 
+
 class CommentInfo:
     def __init__(self,
-                 comment_id:str,
-                 author:str,
-                 content:str,
-                 time:str,
-                 url:str
+                 comment_id: str,
+                 author: str,
+                 content: str,
+                 time: str,
+                 url: str
                  ):
         self.id = comment_id
         self.author = author
@@ -28,14 +31,15 @@ class CommentInfo:
         self.time = time
         self.url = url
 
+
 class ReplyInfo:
     def __init__(self,
-                 reply_id:str,
-                 author:str,
-                 content:str,
-                 time:str,
+                 reply_id: str,
+                 author: str,
+                 content: str,
+                 time: str,
                  ):
         self.id = reply_id
         self.author = author
         self.content = content
-        self.time = time
\ No newline at end of file
+        self.time = time
